@@ -495,8 +495,8 @@ def transform_view_params(params: dict) -> None:
 
     if 'target_code' in params:
         params['method'] = 'target_code'
+        params['view_method'] = 'target_code'
     else:
-        params['method'] = 'word_info'
         if 'query' in params:
             if 'homograph_num' in params:
                 params['query'] += str(params['homograph_num'])
