@@ -89,6 +89,24 @@ def _get_all_pos():
 def _get_all_level():
     return ['1', '2', '3', '0']
 
+def _convert_subject_cat(value):
+    value = int(value)
+
+    if value == 0:
+        values = []
+        for i in range(1, 107):
+            values.append(_convert_subject_cat(i))
+
+        return ','.join(values)
+
+    if value < 40:
+        return str(20000 + value)
+
+    if value < 77:
+        return str(30000 + value - 39)
+
+    return str(40000 + value - 76)
+
 def _convert_sense_cat(value):
     value = int(value)
 
@@ -224,114 +242,7 @@ _ADVANCED_PARAM_MAP = {
     'subject_cat': {
         'name': 'actCategoryList',
         'multi': True,
-        'value': {
-            '1': '20001',
-            '2': '20002',
-            '3': '20003',
-            '4': '20004',
-            '5': '30001',
-            '6': '20005',
-            '7': '30002',
-            '8': '20006',
-            '9': '20007',
-            '10': '30003',
-            '11': '40001',
-            '12': '20008',
-            '13': '30004',
-            '14': '40002',
-            '15': '20009',
-            '16': '30005',
-            '17': '40003',
-            '18': '20010',
-            '19': '30006',
-            '20': '20011',
-            '21': '20012',
-            '22': '20013',
-            '23': '20014',
-            '24': '30007',
-            '25': '40004',
-            '26': '20015',
-            '27': '20016',
-            '28': '30008',
-            '29': '40005',
-            '30': '20017',
-            '31': '30009',
-            '32': '30010',
-            '33': '40006',
-            '34': '30011',
-            '35': '40007',
-            '36': '20018',
-            '37': '20019',
-            '38': '20020',
-            '39': '20021',
-            '40': '20022',
-            '41': '30012',
-            '42': '40008',
-            '43': '20023',
-            '44': '30013',
-            '45': '20024',
-            '46': '30014',
-            '47': '20025',
-            '48': '30015',
-            '49': '30016',
-            '50': '20026',
-            '51': '30017',
-            '52': '40009',
-            '53': '20027',
-            '54': '20028',
-            '55': '20029',
-            '56': '30018',
-            '57': '20030',
-            '58': '20031',
-            '59': '20032',
-            '60': '30019',
-            '61': '20033',
-            '62': '30020',
-            '63': '40010',
-            '64': '20034',
-            '65': '30021',
-            '66': '20035',
-            '67': '30022',
-            '68': '40011',
-            '69': '20036',
-            '70': '30023',
-            '71': '20037',
-            '72': '30024',
-            '73': '40012',
-            '74': '20038',
-            '75': '30025',
-            '76': '20039',
-            '77': '30026',
-            '78': '40013',
-            '79': '30027',
-            '80': '30028',
-            '81': '40014',
-            '82': '30029',
-            '83': '40015',
-            '84': '30030',
-            '85': '40016',
-            '86': '40017',
-            '87': '30031',
-            '88': '40018',
-            '89': '30032',
-            '90': '40019',
-            '91': '30033',
-            '92': '40020',
-            '93': '30034',
-            '94': '30035',
-            '95': '30036',
-            '96': '40021',
-            '97': '40022',
-            '98': '40023',
-            '99': '40024',
-            '100': '40025',
-            '101': '30037',
-            '102': '40026',
-            '103': '40027',
-            '104': '40028',
-            '105': '40029',
-            '106': '40030'
-        }
+        'convert': _convert_subject_cat
     }
 }
 
